.. _traffic_guards:

``traffic_guards`` Block
~~~~~~~~~~~~~~~~~~~~~~~~

Key that configures Traffic Guards for an application

``accounts``
************

Accounts that Traffic Guards will be enabled for. Traffic Guards allow you to 
specify critical clusters that should always have active instances. If a user 
or process tries to delete, disable, or resize the server group, Spinnaker will 
verify the operation will not leave the cluster with no active instances, and 
fail the operation if it would.

    | *Type*: array
    | *Default*: ``[]``
